#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Apr 29 04:11:07 2020

@author: Sara Ben Shabbat
"""
import elasticsearch
from elasticsearch import Elasticsearch

def es_version() -> tuple:    
    return elasticsearch.VERSION

def is_es_active(es: Elasticsearch) -> bool:
    if es.ping():
        return True
    else:
        return False
    
def es_indexes(es: Elasticsearch) -> list:
    return list(es.indices.get_alias().keys())




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="elasticsearch_sbs",
    version="1.0.7",
    author="Sara Ben Shabbat",
    author_email="sarabenshabbat@gmail.com",
    description="A small example package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=["elasticsearch_sbs"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)